about summary refs log tree commit diff
path: root/analyzer/pamgetcolor.c
diff options
context:
space:
mode:
Diffstat (limited to 'analyzer/pamgetcolor.c')
-rw-r--r--analyzer/pamgetcolor.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/analyzer/pamgetcolor.c b/analyzer/pamgetcolor.c
index 2bd3050c..e7e9160d 100644
--- a/analyzer/pamgetcolor.c
+++ b/analyzer/pamgetcolor.c
@@ -250,7 +250,7 @@ parsedCommandLine(int                 argc,
                   const char ** const argv) {
 
     optEntry * option_def;
         /* Instructions to OptParseOptions3 on how to parse our options.
          */
     optStruct3 opt;
 
@@ -273,7 +273,7 @@ parsedCommandLine(int                 argc,
     opt.short_allowed = FALSE;  /* We have no short (old-fashioned) options */
     opt.allowNegNum = FALSE;  /* We have no parms that are negative numbers */
 
-    pm_optParseOptions3(&argc, (char **)argv, opt, sizeof(opt), 0);
+    pm_optParseOptions4(&argc, argv, opt, sizeof(opt), 0);
 
     if (!infileSpec)
         cmdLine.infile = "-";
@@ -250,7 +250,7 @@ parsedCommandLine(int                 argc,
 
     optEntry * option_def;
-        /* Instructions to OptParseOptions3 on how to parse our options.
+        /* Instructions to OptParseOptions4 on how to parse our options.
          */
     optStruct3 opt;